# eCalc CLI

eCalc CLI is provided as a part of the libeCalc package as an example UI for how to use libeCalc, AND for a more
convenient way to use libeCalc without needing to have knowledge about programming.

eCalc CLI is implemented with Typer, that provides helpful interactive help on how to use it.

Start with

```shell
ecalc --help
```

and go on from there.